import { Component } from '@angular/core';
import 'rxjs/add/operator/map'
import { NavController } from 'ionic-angular';
import {UserService} from '../../providers/user-service';
import {LocalStorage} from '../../providers/localStorage';
import { Observable } from 'rxjs/Observable';
import {Geolocation} from "@ionic-native/geolocation";
import {MessageTchatPage} from '../message-tchat/message-tchat';
import {MatrixService} from '../../providers/matrix-service';
import {MessageAlert, MessageOrdre} from '../../app/model/chat.model';

@Component({
  selector: 'page-home',
  templateUrl: 'home.html'
})
export class HomePage {

  lastEvent : Observable<any[]>;
  lat: number;
  lng: number;
  zoom: number = 15;
  apikeyCurrentUser : string;
  apikey: string;
  messageAlert : MessageAlert;
  messageOrdre: MessageOrdre;

  constructor(public navCtrl: NavController,public matrix: MatrixService,  public userService : UserService, public storage: LocalStorage, public geolocation: Geolocation) {
    this.lat = 51.678418;
    this.lng = 7.809007;

  }
  ionViewDidLoad() {
      console.log('ionViewDidLoad HomePage');
      this.loadInfo();
   // this.loadMap();

  }

//save last event id
public initEventId(roomId: string){
  this.matrix.recentEvent().subscribe(res =>{
    console.log(roomId);
    console.log('home initEventId:'+ res.hasOwnProperty(roomId))
    console.log(res);


    if (Object.keys(res).length !== 0 && res.constructor === Object && res.hasOwnProperty(roomId)){
      console.log("my event_id"+ res[roomId].state.events[0].event_id);
    this.storage.setEventId(res[roomId].state.events[0].event_id);
    var statusMessage = this.isAlerteOrOdre(res[roomId].state.events[0].content.body);
    if(statusMessage !== 'false'){
      res[roomId]['status'] = statusMessage;
      if (statusMessage === "ALERTE!")
         this.storage.setMessageAlert(res[roomId]);
      else if (statusMessage === "ORDRE!")
        this.storage.setMessageOrdre(res[roomId]);
    }
  }
  });
}


loadInfo(){
  this.storage.getUser().then(result=>{
    console.log("home loadInfo"+result.groupname);
     this.lastEvent = this.userService.getMyLastEvent(result.groupname)
     this.lastEvent.subscribe(room=>{ if (room.length > 0){console.log("home loadInfo"+room);console.log(room);this.matrix.setRoomId(room[0].roomId);
       this.initEventId(room[0].roomId);}

    })
     this.apikeyCurrentUser = result.apikey;
     this.matrix.setApiKey(this.apikeyCurrentUser);
     this.matrix.syncChat().subscribe(res=>{console.log('home :'+res)});


  });
  this.storage.getMessageAlert().then(result=>{
    this.messageAlert = result;
  }
  )
  this.storage.getMessageOrdre().then(result=>{
    this.messageOrdre = result;
  }
  )
}

public isAlerteOrOdre(message : string): string{
  if (message){
    if (message.search("@alert") > -1){
      return "ALERTE!";
    }
   else if (message.search("@ordre") > -1){
      return "ORDRE!";
    }
    else
      return 'false';
  }
  return 'false';

}

convertirSeconde(sec : number){
  var hour   = (((sec / 60) / 60) % 24);
  var min  = ((sec / 60 ) % 60);
  var seconde = sec % 60;
  return (Math.trunc(hour) > 0) ? Math.trunc(hour)+'h'+Math.trunc(min)+'m'+Math.trunc(seconde)+'s'
                              :(Math.trunc(min) > 0) ? Math.trunc(min)+'m'+Math.trunc(seconde)+'s'
                                          : Math.trunc(seconde)+'s';
}

loadMap(){
  this.geolocation.getCurrentPosition().then((position) =>{
      console.log("location fetched successfully");
      this.lat = position.coords.latitude;
      this.lng = position.coords.longitude;


  }, (err) =>{
      console.log(err);
  });
}

  showMessages(chat, apiKey: string): void {
    console.log("showMessage"+apiKey);

    this.matrix.setRoomId(chat.roomId);
    this.matrix.setApiKey(apiKey);
    this.matrix.joinChat();
    this.navCtrl.push(MessageTchatPage, {chat});
  }


}
