import { Injectable, NgZone } from '@angular/core';
import {Http} from '@angular/http';
import {Message} from '../app/model/chat.model';
import { Observable } from 'rxjs/Observable';
import { AlertController } from 'ionic-angular';


const EventSource : any = window['EventSource'];

export class MatrixInfo{
  roomId: string;
  roomAlias: string;
    apikey: string;


  constructor(roomId:string, roomAlias:string, apiKey:string){
      this.roomId = roomId;
      this.roomAlias = roomAlias;
      this.apikey = apiKey;
  }
}



@Injectable()
export class MatrixService{
  listMessage : Message[] = [];
  matrixInfo : MatrixInfo;

   // apiUrl: string = "https://matrix.org:8448/_matrix/client/r0/"
    /**access token identifier your count  */
    apiUrl: string = "https://matrix.org:8448/_matrix/client/r0/";
    apiKey: string
    roomId : string
    urlEvents : string = "http://localhost/donutMobile/api/public/evenements/group/";
    urlStream : string = "http://localhost/donutMobile/api/public/streaming";
    roomAlias: string;
    constructor(public httpModule:Http, private zone:NgZone, private alertCtrl: AlertController){

    }

    initApiMatrix(roomId:string, roomAlias:string, apiKey:string){
          this.matrixInfo = new MatrixInfo(roomId, roomAlias, apiKey)
     }

    setRoomId(roomId: string){
      console.log("matrix room id :"+ roomId)
      this.roomId = roomId;
    }
    seRoomAlias(roomAlias: string){
      this.roomAlias = roomAlias;
    }
    setApiKey(apiKey: string){
      console.log("matrix apikey :"+ apiKey)
      this.apiKey = apiKey
    }

    //@TODO list event by user id
    listEventRoom(groupname) {
      return this.httpModule.get(this.urlEvents+groupname).map(res =>res.json());
    }

    sendChat(data){
      return new Promise((resolve, reject) => {
        this.httpModule.post(this.apiUrl+'rooms/'+this.roomId+'/send/m.room.message?access_token='+this.apiKey,  JSON.stringify(data))
          .subscribe(res => {
            resolve(res);
          }, (err) => {
            reject(err);
          });
      });
    }
  getRoomId(): string{
  return this.roomId;
  }

  syncChat(){
    return this.httpModule.get(this.apiUrl+'sync?access_token='+this.apiKey)
  .map(res =>(res.json().rooms.join.hasOwnProperty(this.roomId))?res.json().rooms.join[this.roomId].timeline.events : null)
  }

    joinChat(){
      return new Promise((resolve, reject) => {
        this.httpModule.post(this.apiUrl+'rooms/'+this.roomId+'/join?access_token='+this.apiKey,  JSON.stringify(''))
          .subscribe(res => {
            resolve(res);
          }, (err) => {
           // reject(err);
            console.log(err._body)
            let alert = this.alertCtrl.create({
              title: 'Ce Tchat existe plus ou a été supprimé',
              buttons: ['OK']
            });
            alert.present();

          });
      });

    }

    recentEvent(){
      return this.httpModule.get(this.apiUrl+'sync?filter={"room":{"timeline":{"limit":1}}}&access_token='+this.apiKey)
      .map(res => res.json().rooms.join)

    }

    asyncObservable() {
      return new Observable(observer => {
        setInterval(() => {
          observer.next(this.httpModule.get(this.apiUrl+'sync?filter={"room":{"timeline":{"limit":1}}}&access_token='+this.apiKey));
        }, 1000)
      })
  }
  test(){

    return new Promise((resolve, reject) => {
      this.httpModule.get(this.urlStream+'/'+this.apiKey)
        .subscribe(res => {
          resolve(res);
        }, (err) => {
          reject(err);
        });
    });

  }

  stremingChat(): Observable<Message>{
    return new Observable<Message>(obs=>{
      const fx = new EventSource(this.urlStream+'/'+this.apiKey)
        fx.onmessage = evt =>{
          const data = JSON.parse(evt.data);

          if (data.rooms.join.hasOwnProperty(this.roomId)){
            console.log(data.rooms.join[this.roomId].timeline.events);
            this.zone.run(() => obs.next(data.rooms.join[this.roomId].timeline.events))
          }
          else{
            return ()=>fx.close();
          }
        };
        return ()=>fx.close();
    });
  }

  eventLastActivity(since: string){
    return this.httpModule.get(this.apiUrl+'sync?since='+since+'&access_token='+this.apiKey)
    .map(res => res.json().rooms.join[this.roomId].timeline.events)
  }

  if

}
